Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: ash/shell.h

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shell.h
diff --git a/ash/shell.h b/ash/shell.h
index bff6a25023d78bda06375a796bdd5384a3cd7258..db1a8d7c7f366fd25bfd42d2338d4d236bc9b800 100644
--- a/ash/shell.h
+++ b/ash/shell.h
@@ -121,7 +121,7 @@ class LockStateController;
class LogoutConfirmationController;
class LockScreenController;
class MagnificationController;
-class MaximizeModeController;
+class TabletModeController;
class MediaController;
class MouseCursorEventFilter;
class MruWindowTracker;
@@ -294,8 +294,8 @@ class ASH_EXPORT Shell : public SessionObserver,
// Deactivates the virtual keyboard.
void DeactivateKeyboard();
// Test if MaximizeModeWindowManager is not enabled, and if
// MaximizeModeController is not currently setting a display rotation. Or if
// the |resolution_notification_controller_| is not showing its confirmation
// dialog. If true then changes to display settings can be saved.
bool ShouldSaveDisplaySettings();
@@ -333,8 +333,8 @@ class ASH_EXPORT Shell : public SessionObserver,
LockScreenController* lock_screen_controller() {
return lock_screen_controller_.get();
}
- MaximizeModeController* maximize_mode_controller() {
- return maximize_mode_controller_.get();
+ TabletModeController* tablet_mode_controller() {
+ return tablet_mode_controller_.get();
}
MediaController* media_controller() { return media_controller_.get(); }
MruWindowTracker* mru_window_tracker() { return mru_window_tracker_.get(); }
@@ -567,16 +567,16 @@ class ASH_EXPORT Shell : public SessionObserver,
// TODO(oshima): Investigate if we can merge this and |OnLoginStateChanged|.
void UpdateAfterLoginStatusChange(LoginStatus status);
// Notifies observers that maximize mode has started, windows might still
// animate.
- void NotifyMaximizeModeStarted();
+ void NotifyTabletModeStarted();
- // Notifies observers that maximize mode is about to end.
- void NotifyMaximizeModeEnding();
+ // Notifies observers that tablet mode is about to end.
+ void NotifyTabletModeEnding();
- // Notifies observers that maximize mode has ended, windows might still be
+ // Notifies observers that tablet mode has ended, windows might still be
// returning to their original position.
- void NotifyMaximizeModeEnded();
+ void NotifyTabletModeEnded();
// Notifies observers that overview mode is about to be started (before the
// windows get re-arranged).
@@ -698,7 +698,7 @@ class ASH_EXPORT Shell : public SessionObserver,
std::unique_ptr<LocaleNotificationController> locale_notification_controller_;
std::unique_ptr<LockScreenController> lock_screen_controller_;
std::unique_ptr<LogoutConfirmationController> logout_confirmation_controller_;
- std::unique_ptr<MaximizeModeController> maximize_mode_controller_;
+ std::unique_ptr<TabletModeController> tablet_mode_controller_;
std::unique_ptr<MediaController> media_controller_;
std::unique_ptr<MruWindowTracker> mru_window_tracker_;
std::unique_ptr<NewWindowController> new_window_controller_;
@@ -294,8 +294,8 @@ class ASH_EXPORT Shell : public SessionObserver,
// Deactivates the virtual keyboard.
void DeactivateKeyboard();
- // Test if MaximizeModeWindowManager is not enabled, and if
- // MaximizeModeController is not currently setting a display rotation. Or if
+ // Test if TabletModeWindowManager is not enabled, and if
+ // TabletModeController is not currently setting a display rotation. Or if
// the |resolution_notification_controller_| is not showing its confirmation
// dialog. If true then changes to display settings can be saved.
@@ -567,16 +567,16 @@ class ASH_EXPORT Shell : public SessionObserver,
// TODO(oshima): Investigate if we can merge this and |OnLoginStateChanged|.
void UpdateAfterLoginStatusChange(LoginStatus status);
- // Notifies observers that maximize mode has started, windows might still
+ // Notifies observers that tablet mode has started, windows might still
// animate.

Powered by Google App Engine
This is Rietveld 408576698